ifgen.commands package — docs

Skip to main content
`Ctrl`+`K`

# ifgen.commands package

## Submodules

## ifgen.commands.all module

A module aggregating package commands.

ifgen.commands.all.commands() → list[tuple[str, str, Callable[[ArgumentParser], Callable[[Namespace], int]]]]

  Get this package’s commands.

## ifgen.commands.gen module

An entry-point for the ‘gen’ command.

ifgen.commands.gen.add_gen_cmd(parser: ArgumentParser) → Callable[[Namespace], int]

  Add gen-command arguments to its parser.

ifgen.commands.gen.gen_cmd(args: Namespace) → int

  Execute the gen command.

## ifgen.commands.svd module

An entry-point for the ‘svd’ command.

ifgen.commands.svd.add_svd_cmd(parser: ArgumentParser) → Callable[[Namespace], int]

  Add svd-command arguments to its parser.

ifgen.commands.svd.svd_cmd(args: Namespace) → int

  Execute the svd command.

## Module contents